@@ -74,7 +74,7 @@ void do_rbvlog(int *n, double *dep, double *sim)
 
   for(i=0;i<*n;i++) 
   {
-    delta = eps = llim = R_pow(DOUBLE_EPS, 0.5);
+    delta = eps = llim = R_pow(DBL_EPSILON, 0.5);
     ulim = 1 - llim;
     ilen = 1;
     midpt = 0.5;
@@ -82,7 +82,7 @@ void do_rbvlog(int *n, double *dep, double *sim)
     uval = ccbvlog(ulim, sim[2*i+1], sim[2*i+0], *dep);
     if(!(sign(lval) != sign(uval))) 
       error("values at end points are not of opposite sign");
-    for(j=0;j<DOUBLE_DIGITS;j++) {
+    for(j=0;j<DBL_MANT_DIG;j++) {
       ilen = ilen/2;
       midpt = llim + ilen;
       midval = ccbvlog(midpt, sim[2*i+1], sim[2*i+0], *dep);
@@ -96,7 +96,7 @@ void do_rbvlog(int *n, double *dep, double *sim)
         llim = midpt;
         lval = midval;
       }
-      if(j == DOUBLE_DIGITS-1) 
+      if(j == DBL_MANT_DIG-1) 
         error("numerical problem in root finding algorithm");
     }
     sim[2*i+0] = midpt;
@@ -111,7 +111,7 @@ void do_rbvalog(int *n, double *dep, double *asy, double *sim)
 
   for(i=0;i<*n;i++) 
   {
-    delta = eps = llim = R_pow(DOUBLE_EPS, 0.5);
+    delta = eps = llim = R_pow(DBL_EPSILON, 0.5);
     ulim = 1 - llim;
     ilen = 1;
     midpt = 0.5;
@@ -119,7 +119,7 @@ void do_rbvalog(int *n, double *dep, double *asy, double *sim)
     uval = ccbvalog(ulim, sim[2*i+1], sim[2*i+0], *dep,asy[0],asy[1]);
     if(!(sign(lval) != sign(uval))) 
       error("values at end points are not of opposite sign");
-    for(j=0;j<DOUBLE_DIGITS;j++) {
+    for(j=0;j<DBL_MANT_DIG;j++) {
       ilen = ilen/2;
       midpt = llim + ilen;
       midval = ccbvalog(midpt, sim[2*i+1], sim[2*i+0], *dep,asy[0],asy[1]);
@@ -133,7 +133,7 @@ void do_rbvalog(int *n, double *dep, double *asy, double *sim)
         llim = midpt;
         lval = midval;
       }
-      if(j == DOUBLE_DIGITS-1) 
+      if(j == DBL_MANT_DIG-1) 
         error("numerical problem in root finding algorithm");
     }
     sim[2*i+0] = midpt;
@@ -148,7 +148,7 @@ void do_rbvnlog(int *n, double *dep, double *sim){
 
   for(i=0;i<*n;i++) 
   {
-    delta = eps = llim = R_pow(DOUBLE_EPS, 0.5);
+    delta = eps = llim = R_pow(DBL_EPSILON, 0.5);
     ulim = 1 - llim;
     ilen = 1;
     midpt = 0.5;
@@ -156,7 +156,7 @@ void do_rbvnlog(int *n, double *dep, double *sim){
     uval = ccbvnlog(ulim, sim[2*i+1], sim[2*i+0], *dep);
     if(!(sign(lval) != sign(uval))) 
       error("values at end points are not of opposite sign");
-    for(j=0;j<DOUBLE_DIGITS;j++) {
+    for(j=0;j<DBL_MANT_DIG;j++) {
       ilen = ilen/2;
       midpt = llim + ilen;
       midval = ccbvnlog(midpt, sim[2*i+1], sim[2*i+0], *dep);
@@ -170,7 +170,7 @@ void do_rbvnlog(int *n, double *dep, double *sim){
         llim = midpt;
         lval = midval;
       }
-      if(j == DOUBLE_DIGITS-1) 
+      if(j == DBL_MANT_DIG-1) 
         error("numerical problem in root finding algorithm");
     }
     sim[2*i+0] = midpt;
@@ -185,7 +185,7 @@ void do_rbvanlog(int *n, double *dep, double *asy, double *sim)
 
   for(i=0;i<*n;i++) 
   {
-    delta = eps = llim = R_pow(DOUBLE_EPS, 0.5);
+    delta = eps = llim = R_pow(DBL_EPSILON, 0.5);
     ulim = 1 - llim;
     ilen = 1;
     midpt = 0.5;
@@ -193,7 +193,7 @@ void do_rbvanlog(int *n, double *dep, double *asy, double *sim)
     uval = ccbvanlog(ulim, sim[2*i+1], sim[2*i+0], *dep,asy[0],asy[1]);
     if(!(sign(lval) != sign(uval))) 
       error("values at end points are not of opposite sign");
-    for(j=0;j<DOUBLE_DIGITS;j++) {
+    for(j=0;j<DBL_MANT_DIG;j++) {
       ilen = ilen/2;
       midpt = llim + ilen;
       midval = ccbvanlog(midpt, sim[2*i+1], sim[2*i+0], *dep,asy[0],asy[1]);
@@ -207,7 +207,7 @@ void do_rbvanlog(int *n, double *dep, double *asy, double *sim)
         llim = midpt;
         lval = midval;
       }
-      if(j == DOUBLE_DIGITS-1) 
+      if(j == DBL_MANT_DIG-1) 
         error("numerical problem in root finding algorithm");
     }
     sim[2*i+0] = midpt;
@@ -224,7 +224,7 @@ void do_rbvmix(int *n, double *alpha, double *sim)
 
   for(i=0;i<*n;i++) 
   {
-    delta = eps = llim = R_pow(DOUBLE_EPS, 0.5);
+    delta = eps = llim = R_pow(DBL_EPSILON, 0.5);
     ulim = 1 - llim;
     ilen = 1;
     midpt = 0.5;
@@ -232,7 +232,7 @@ void do_rbvmix(int *n, double *alpha, double *sim)
     uval = ccbvmix(ulim, sim[2*i+1], sim[2*i+0], *alpha);
     if(!(sign(lval) != sign(uval))) 
       error("values at end points are not of opposite sign");
-    for(j=0;j<DOUBLE_DIGITS;j++) {
+    for(j=0;j<DBL_MANT_DIG;j++) {
       ilen = ilen/2;
       midpt = llim + ilen;
       midval = ccbvmix(midpt, sim[2*i+1], sim[2*i+0], *alpha);
@@ -246,7 +246,7 @@ void do_rbvmix(int *n, double *alpha, double *sim)
         llim = midpt;
         lval = midval;
       }
-      if(j == DOUBLE_DIGITS-1) 
+      if(j == DBL_MANT_DIG-1) 
         error("numerical problem in root finding algorithm");
     }
     sim[2*i+0] = midpt;
@@ -260,7 +260,7 @@ void do_rbvamix(int *n, double *alpha, double *beta, double *sim)
 
   for(i=0;i<*n;i++) 
   {
-    delta = eps = llim = R_pow(DOUBLE_EPS, 0.5);
+    delta = eps = llim = R_pow(DBL_EPSILON, 0.5);
     ulim = 1 - llim;
     ilen = 1;
     midpt = 0.5;
@@ -268,7 +268,7 @@ void do_rbvamix(int *n, double *alpha, double *beta, double *sim)
     uval = ccbvamix(ulim, sim[2*i+1], sim[2*i+0], *alpha, *beta);
     if(!(sign(lval) != sign(uval))) 
       error("values at end points are not of opposite sign");
-    for(j=0;j<DOUBLE_DIGITS;j++) {
+    for(j=0;j<DBL_MANT_DIG;j++) {
       ilen = ilen/2;
       midpt = llim + ilen;
       midval = ccbvamix(midpt, sim[2*i+1], sim[2*i+0], *alpha, *beta);
@@ -282,7 +282,7 @@ void do_rbvamix(int *n, double *alpha, double *beta, double *sim)
         llim = midpt;
         lval = midval;
       }
-      if(j == DOUBLE_DIGITS-1) 
+      if(j == DBL_MANT_DIG-1) 
         error("numerical problem in root finding algorithm");
     }
     sim[2*i+0] = midpt;
